@@ -24,23 +24,40 @@ class Collect:
         executor = ThreadPoolExecutor(10)
         with progress_bar as p:
             class_task = p.add_task("[red]CLASSES", total=len(classes))
-            for cdclass in classes:
-                doc_task = p.add_task(f"[green]DOCUMENTS FOR CLASS {cdclass}")
-                logger.info(f"Getting documents for class {cdclass}")
-                await asyncio.gather(
-                    *[
-                        loop.run_in_executor(
-                            executor,
-                            functools.partial(
-                                self.parallel_docs, p, doc_task, doc, cdclass
-                            ),
-                        )
-                        for doc in self.get_keys(cdclass)
-                    ]
+            await asyncio.gather(
+                *[
+                    loop.run_in_executor(
+                        executor,
+                        functools.partial(
+                            self.parallel_classes, p, class_task, cdclass
+                        ),
+                    )
+                    for cdclass in classes
+                ]
+            )
+
+    def parallel_classes(self, progress, task, cdclass):
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+        executor = ThreadPoolExecutor(10)
+
+        doc_task = progress.add_task(f"[green]DOCUMENTS FOR CLASS {cdclass}")
+        logger.info(f"Getting documents for class {cdclass}")
+        parallel_docs = asyncio.gather(
+            *[
+                loop.run_in_executor(
+                    executor,
+                    functools.partial(
+                        self.parallel_docs, progress, doc_task, doc, cdclass
+                    ),
                 )
-                p.stop_task(doc_task)
-                logger.info(f"Finished class {cdclass}")
-                p.advance(class_task)
+                for doc in self.get_keys(cdclass)
+            ]
+        )
+        loop.run_until_complete(parallel_docs)
+        progress.stop_task(doc_task)
+        logger.info(f"Finished class {cdclass}")
+        progress.advance(task)
 
     def parallel_docs(self, progress, task, doc, cdclass):
         logger.info(f"Getting key {doc} in class {cdclass}")
